@@ -25,8 +25,7 @@
 #include <QModelIndex>
 
 class KRecursiveFilterProxyModel;
-namespace Akonadi
-{
+namespace Akonadi {
 class EntityTreeModel;
 class ChangeRecorder;
 class CollectionRequester;
@@ -41,10 +40,10 @@ class KNoteCollectionDisplayProxyModel : public QIdentityProxyModel
 public:
     explicit KNoteCollectionDisplayProxyModel(QObject *parent = nullptr);
 
-    QVariant data(const QModelIndex &index, int role) const Q_DECL_OVERRIDE;
+    QVariant data(const QModelIndex &index, int role) const override;
 
-    bool setData(const QModelIndex &index, const QVariant &_data, int role) Q_DECL_OVERRIDE;
-    Qt::ItemFlags flags(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    bool setData(const QModelIndex &index, const QVariant &_data, int role) override;
+    Qt::ItemFlags flags(const QModelIndex &index) const override;
 
     QHash<Akonadi::Collection, bool> displayCollection() const;
 
